AudioProbe class

A probe recording audio from the microphone. It starts recording on onResume and stops recording on onPause, and post the recorded MediaData object to the measurements stream.

Note that this probe generates a lot of data and should be used with caution.

Also note that this probe records raw sound directly from the microphone and hence records everything - including human speech - in its proximity.

The audio probe generates an MediaData data measurement that holds the meta-data for each recording along with the actual recording in an audio file. How to upload or store this data to a data backend is up to the implementation of the DataManager, which is used in the Study.

Inheritance
  • Object
  • AbstractExecutor<Measure>
  • Probe
  • AudioProbe

Constructors

AudioProbe()

Properties

configuration → Measure?
The configuration of this executor as set in initialize.
no setterinherited
deployment → SmartphoneDeployment?
The deployment that this executor is part of executing.
no setterinherited
deviceManager ↔ DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>
The device that this probes uses to collect data.
getter/setter pairinherited
enabled bool
Is this probe enabled, i.e. available for collection of data using the resume method.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isRecording bool
no setter
measure → Measure?
The Measure that configures this probe.
no setterinherited
measurements Stream<Measurement>
The stream of Measurement collected by this executor.
no setterinherited
permissions List<Permission>
The list of permissions needed for this probe.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingConfiguration → SamplingConfiguration?
The sampling configuration for this probe.
no setterinherited
samplingState → SamplingState
The runtime sampling state of this executor.
no setterinherited
state → ExecutorState
The runtime state of this executor.
no setterinherited
stateEvents Stream<ExecutorState>
The runtime state changes of this executor.
no setterinherited
type String?
The data type this probe is collecting.
no setterinherited

Methods

addError(Object error, [StackTrace? stacktrace]) → void
Add error to the measurements stream.
inherited
addMeasurement(Measurement measurement) → void
Add measurement to the measurements stream.
inherited
arePermissionsGranted() Future<bool>
Does this probe has the permissions needed to run?
inherited
dispose() → void
Dispose of this executor.
inherited
error() → void
inherited
initialize(Measure configuration, [SmartphoneDeployment? deployment]) → void
Configure and initialize the executor before using it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() Future<void>
Callback when this executor is disposed.
override
onInitialize() bool
Callback when this executor is initialized. Returns true if successfully initialized, false otherwise.
override
onPause() Future<bool>
Callback when this executor is paused. Returns true if successfully paused, false otherwise.
override
onResume() Future<bool>
Callback when this executor is resumed. Returns true if successfully resumed, false otherwise.
override
pause() → void
Pause the executor. Paused until resume is called.
inherited
pauseButShouldBeResumed() → void
Pause the executor but mark it to be resumed when possible.
inherited
requestPermissions() Future<bool>
Request the permissions needed for this probe to run. Return true if all permissions are granted. Only used on Android - iOS automatically request permissions when a resource (like the microphone) is accessed.
inherited
resume() → void
Resume the executor.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited