MediaSamplingPackage class

A sampling package for capturing audio (incl. noise) and video (incl. images).

To use this package, register it in the carp_mobile_sensing package using

  SamplingPackageRegistry.register(MediaSamplingPackage());
Inheritance
  • Object
  • SamplingPackage
  • SmartphoneSamplingPackage
  • MediaSamplingPackage

Constructors

MediaSamplingPackage()

Properties

dataTypes → List<DataTypeMetaData>
The list of data type this package supports.
no setterinherited
deviceManager → DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>
Get the DeviceManager for the device used by this package.
no setterinherited
deviceType → String
What device type is this package using?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchemes → DataTypeSamplingSchemeMap
The default sampling schemes for all dataTypes in this package.
no setteroverride

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Note that type should be one of the dataTypes that this package supports. Returns null if a probe cannot be created for the type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

AUDIO → const String
Measure type for one-time collection of audio from the phone's microphone.
IMAGE → const String
MEDIA_FILES_PATH → const String
The name of the folder used for storing audio files.
NOISE → const String
Measure type for periodic collection of noise data from the phone's microphone.
VIDEO → const String